@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Create network transition chord progressions
 
-our $VERSION = '0.0002';
+our $VERSION = '0.0003';
 
 use Data::Dumper::Compact qw(ddc);
 use Graph::Directed;
@@ -73,6 +73,13 @@ has tonic => (
 );
 
 
+has resolve => (
+    is      => 'ro',
+    isa     => sub { die "$_[0] is not a valid boolean" unless $_[0] =~ /^[01]$/ },
+    default => sub { 1 },
+);
+
+
 has flat => (
     is      => 'ro',
     isa     => sub { die "$_[0] is not a valid boolean" unless $_[0] =~ /^[01]$/ },
@@ -111,10 +118,13 @@ sub generate {
     for my $n (1 .. $self->max) {
         if ($n == 1) {
             $v = $self->tonic ? 1 : (keys %{ $self->net })[int rand keys %{ $self->net }];
-            push @progression, $v;
-            next;
         }
-        $v = $self->graph->random_successor($v);
+        elsif ($n == $self->max) {
+            $v = $self->resolve ? 1 : (keys %{ $self->net })[int rand keys %{ $self->net }];
+        }
+        else {
+            $v = $self->graph->random_successor($v);
+        }
         push @progression, $v;
     }
     print "Progression: @progression\n" if $self->verbose;
@@ -166,7 +176,7 @@ Music::Chord::Progression - Create network transition chord progressions
 
 =head1 VERSION
 
-version 0.0002
+version 0.0003
 
 =head1 SYNOPSIS
 
@@ -235,6 +245,12 @@ Whether to start the progression with the tonic chord or not.
 
 Default: C<1>
 
+=head2 resolve
+
+Whether to end the progression with the tonic chord or not.
+
+Default: C<1>
+
 =head2 flat
 
 Whether to use flats instead of sharps in the chords or not.
